pub fn parse_flags(flags: u64) -> Option<BlockingMode>Expand description
Will extract all the information from the flags, will return None if the argument
is invalid
pub fn parse_flags(flags: u64) -> Option<BlockingMode>Will extract all the information from the flags, will return None if the argument
is invalid